@@ -27,12 +27,19 @@ will be presented to the user.
 
 import sys
 
-from framework import main, Stop
+from yaclifw.framework import main, Stop
+from yaclifw.version import Version
 
+from omego import __file__ as module_file
+from convert import ConvertCommand
+from upgrade import InstallCommand
 from upgrade import UpgradeCommand
 from artifacts import DownloadCommand
 from db import DbCommand
-from version import Version
+
+
+class OmegoVersion(Version):
+    FILE = module_file
 
 
 def entry_point():
@@ -41,13 +48,18 @@ def entry_point():
     if Stop is raised, calls sys.exit()
     """
     try:
-        main(items=[
+        main("omego", items=[
+            (InstallCommand.NAME, InstallCommand),
             (UpgradeCommand.NAME, UpgradeCommand),
+            (ConvertCommand.NAME, ConvertCommand),
             (DownloadCommand.NAME, DownloadCommand),
             (DbCommand.NAME, DbCommand),
-            (Version.NAME, Version)])
+            (Version.NAME, OmegoVersion)])
     except Stop, stop:
-        print stop,
+        if stop.rc != 0:
+            print "ERROR:", stop
+        else:
+            print stop
         sys.exit(stop.rc)
 
 
